from urllib import request
from urllib.error import HTTPError
from time import strftime
try:
    import simplejson as json
except ImportError:
    import json


class Scrobbler:

    def __init__(self, user):
        self.user = user
        self.api_key = '4829c7fa580a0b6c93f64610aeaf9e67'
        self.format = 'json'
        self.url = 'http://ws.audioscrobbler.com/2.0/?method=user.getrecenttracks&user='+self.user+'&api_key='+self.api_key+'&format='+self.format
        self.request()
        self.get_playing()
        self.get_artist()
        self.get_title()

    def request(self):
        self.data = None
        try:
            response = request.urlopen(self.url)
            encoding = response.headers.get_content_charset()
            data = response.read().decode(encoding)
            self.data = json.loads(data)
        except HTTPError:
            Scrobbler.log('error', 'HTTP Error 503: Service Unavailable')
            pass
        return self.data

    def get_playing(self):
        self.np = False
        try:
            self.np = self.data['recenttracks']['track'][0]['@attr']['nowplaying']
        except KeyError:
            Scrobbler.log('error', 'KeyError occured.')
        finally:
            if self.np == 'true':
                self.np = True
            else:
                self.np = False
            return self.np

    def get_artist(self):
        self.artist = None
        if self.np:
            self.artist = self.data['recenttracks']['track'][0]['artist']['#text']
        return self.artist

    def get_title(self):
        self.title = None
        if self.np:
            self.title = self.data['recenttracks']['track'][0]['name']
        return self.title

    @classmethod
    def log(cls, level, message,):
        level = level.upper()
        time = strftime('%Y-%m-%d %H:%M:%S')
        print('%s [%s] [%s] %s' % (time, cls.__name__, level, message))



from distutils.core import setup

setup(
    name='XolNowPlaying',
    version='0.1.6',
    author='Jonas Svarvaa',
    author_email='jonassvarvaa@gmail.com',
    packages=['xolnowplaying'],
    scripts=['bin/np.py'],
    url='http://pypi.python.org/pypi/XolNowPlaying',
    license='LICENSE.txt',
    description='Read from AudioScrobbler and write to file.',
    long_description=open('README.rst').read(),
    install_requires=[
        "docopt == 0.6.1",
    ],
)



#!/usr/env python
"""XolNowPlaying

Usage:
    np.py -u <user>
    np.py -u <user> -r <refresh_rate>
    np.py (-h | --help)
    np.py --version

Options:
    -h --help           Show this help.
    --version           Show script version.
    -u <user>           User to look up.
    -r <refresh_rate>   Refresh every <refresh_rate> seconds.

"""
from docopt import docopt
from time import sleep
from xolnowplaying.scrobbler import Scrobbler
import os

class XolNowPlaying:

    def __init__(self, user):
        self.filename = os.getenv('HOME') + '/np.txt'
        self.refresh(user)

    def refresh(self, user):
        self.scrobbler = Scrobbler(user)

    def run(self):
        string = ''
        if self.is_playing:
            string = '%s - %s' % (self.artist, self.title)
            if self.write_to_file(self.filename, string):
                Scrobbler.log('info ', string)
        else:
            string = ''
            self.write_to_file(self.filename, string)

    def write_to_file(self, filename, string):
        with open(filename, 'w+') as f:
            read = f.readline()
        f.close()
        if not read == string:
            with open(filename, 'w') as f:
                try:
                    f.write(string)
                except UnicodeEncodeError:
                    pass
            f.close()
            return True
        else:
            return False

    def main(self, arguments):
        if not arguments['-r']:
            self.run()
        else:
            Scrobbler.log('debug', 'Refreshing every %s seconds' % (arguments['-r']))
            while True:
                self.run()
                sleep(float(arguments['-r']))
                self.refresh(arguments['-u'])
        return 0

    @property
    def is_playing(self):
        return self.scrobbler.np or False

    @property
    def artist(self):
        return self.scrobbler.artist or None

    @property
    def title(self):
        return self.scrobbler.title or None


if __name__ == '__main__':
    arguments = docopt(__doc__, version='xolnowplaying v0.1.6')
    np = XolNowPlaying(arguments['-u'])
    exit(np.main(arguments))
